junitmsgfmt — Translate Toolkit 3.1.0 documentation

Translate Toolkit 3.1.0

- Site
  - Features
  - Installation
  - Converters
  - Tools
  - Scripts
  - Use Cases
  - Supported formats
  - Translate Styleguide
  - Documentation
  - Building
  - Testing
  - Command Line Functional Testing
  - Contributing
  - Translate Toolkit Developers Guide
  - Making a Translate Toolkit Release
  - Deprecation of Features
  - Release Notes
  - History of the Translate Toolkit
  - License
  - API
- Page
  - junitmsgfmt
    - Usage
- « porestructure
- tmserver »

# junitmsgfmt

New in version 1.7.

Run msgfmt and provide JUnit type output for use in continuous integration systems like Hudson and Jenkins.

## Usage

    junitmsgfmt po/*.po > msgfmt_junit.xml